package com.lantone.qc.kernel.catalogue.behospitalized;

import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.kernel.util.CatalogueUtil;
import com.lantone.qc.kernel.util.KernelConstants;
import com.lantone.qc.kernel.util.RedisUtil;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.OutputInfo;
import com.lantone.qc.pub.model.doc.BeHospitalizedDoc;
import com.lantone.qc.pub.model.entity.Clinical;
import com.lantone.qc.pub.model.entity.Diag;
import com.lantone.qc.pub.model.entity.PD;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.List;
import java.util.Map;


/**
 * @ClassName : BEH0002
 * @Description : 主诊断与主诉不符
 * @Author : 楼辉荣
 * @Date: 2020-03-06 17:28
 */
@Component
public class BEH0002 extends QCCatalogue {
    @Autowired
    private RedisUtil redisUtil;

    public void start(InputInfo inputInfo, OutputInfo outputInfo) {
        List<Diag> diags = inputInfo.getBeHospitalizedDoc().getInitialDiagLabel().getDiags();
        String mainDiag = diags.get(0).getName();
        status = "0";
       List<String> symptoms=null;
       Map<String, Map<String, Object>> diagMap =(Map<String, Map<String, Object>>) redisUtil.get(KernelConstants.CONCEPT_DIAG_PROPERTY_MAP);
       Map<String, Object> map = (Map<String, Object>) diagMap.get(mainDiag);
       if(map != null || map.size() >0){
           symptoms = (List<String>) map.get("symptoms");
       }
        List<Clinical> clinicals = inputInfo.getBeHospitalizedDoc().getPresentLabel().getClinicals();
        if(clinicals != null && clinicals.size()>0){
            for (Clinical clinical:clinicals) {
                String clinicalName = clinical.getName();
                if(symptoms != null && !symptoms.contains(clinicalName)){
                    if(StringUtils.isEmpty(info)){
                        info = clinicalName;
                    }else {
                        info = info +"," +clinicalName;
                    }
                }
            }
        }
        if(StringUtils.isNotEmpty(info)){
            status = "-1";
        }
    }
}