package com.lantone.qc.kernel.util;

import com.google.common.collect.Lists;
import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.pub.model.entity.Diag;
import com.lantone.qc.pub.util.ListUtil;
import com.lantone.qc.pub.util.StringUtil;
import lombok.Getter;
import lombok.Setter;

import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

/**
 * @ClassName : CatalogueUtil
 * @Description :
 * @Author : 楼辉荣
 * @Date: 2020-03-09 10:59
 */
@Getter
@Setter
public class CatalogueUtil {
    public static Map<String, QCCatalogue> qcCatalogueMap = new HashMap<>();


    public static boolean isEmpty(String content) {
        return StringUtil.isBlank(removeSpecialChar(content));
    }

    public static String removeSpecialChar(String content) {
        if (StringUtil.isEmpty(content)) {
            return "";
        }
        return content.replaceAll("[\r\n|/r/n|\n|/n|/t|\t]", "").trim();
    }

    public static String[] extractDigit(String value) {
        String[] res = new String[2];
        try {
            String regTime = "([\\d]+)([\\u4e00-\\u9fa5]+)";
            Pattern pattern = Pattern.compile(regTime);
            Matcher matcher = pattern.matcher(value);
            if (matcher.find(0)) {
                res[0] = matcher.group(1);
                res[1] = matcher.group(2);
            } else {
                res[0] = value;
                res[1] = "";
            }
        } catch (Exception ex) {
            ex.printStackTrace();
        }
        return res;
    }

    /**
     * words中的所有词，哪些不包含在text文本里的引号下面
     * 如：
     * word：{"高血压","糖尿病","白血病","感冒"}
     * text: 否认患有"高血压，糖尿病等"，"白血病",感冒
     * 结果：感冒
     *
     * @param words
     * @param text
     * @return
     */
    public static List<String> noInQuotes(List<String> words, String text) {
        List<String> retWords = Lists.newArrayList();
        if (ListUtil.isNotEmpty(words) && StringUtil.isNotBlank(text)) {
            List<String> sections = Lists.newArrayList();
            int index = 0;
            for (String txt : text.split("\"")) {
                if (index % 2 == 1) {
                    sections.add(txt);
                }
                index++;
            }
            for (String word : words) {
                if (StringUtil.isNotBlank(word) && sections.stream().filter(section -> section.indexOf(word) != -1).count() == 0) {
                    retWords.add(word);
                }
            }
        }
        return retWords;
    }

    /**
     * 从现有诊断中筛选符合某一属性值的诊断
     *
     * @param diags
     * @param nature
     * @param natureValue
     * @return
     */
    public static List<Diag> filterDiagsByNature(List<Diag> diags, String nature, String natureValue) {
        if (ListUtil.isEmpty(diags) || StringUtil.isBlank(nature) || StringUtil.isBlank(natureValue)) {
            return null;
        }
        List<Diag> retDiags = Lists.newArrayList();
        RedisUtil redisUtil = SpringContextUtil.getBean("redisUtil");
        Map<String, Map<String, Object>> diagCache = (Map) redisUtil.get("concept_diag_property_map");
        diags.forEach(i -> {
            if (i != null && StringUtil.isNotBlank(i.getName())) {
                Map<String, Object> diagDetailMap = diagCache.get(i.getName());
                if (diagDetailMap != null) {
                    String natureValue_ = (String) diagDetailMap.get(nature);
                    if (StringUtil.isNotBlank(natureValue_) && natureValue_.equals(natureValue)) {
                        retDiags.add(i);
                    }
                }
            }
        });
        return retDiags;
    }

}